@@ -3,6 +3,7 @@
 
 """This module provides generators for http and https proxies."""
 
+
 import json
 import requests
 
@@ -20,7 +21,7 @@ def get_proxies(url, proxy_type=None):
 
 def get_http_proxy(url):
     """Create a generator of http proxies."""
-    http_proxies = get_proxies(url, 'http')
+    http_proxies = get_proxies(url, proxy_type='http')
     num_proxies = len(http_proxies)
     i = 0
     while i < num_proxies:
@@ -30,7 +31,7 @@ def get_http_proxy(url):
 
 def get_https_proxy(url):
     """Create a generator of https proxies."""
-    https_proxies = get_proxies(url, 'https')
+    https_proxies = get_proxies(url, proxy_type='https')
     num_proxies = len(https_proxies)
     i = 0
     while i < num_proxies:
@@ -38,19 +39,18 @@ def get_https_proxy(url):
         i += 1
 
 
-def get_proxies_from_json(proxy_json, proxy_type=None):
+def get_proxies_from_json(json_str, proxy_type=None):
     """Return a list of proxy entries from given json_data."""
-    if proxy_type is None:
-        proxies = proxy_json
-    else:
-        proxies = [p for p in proxy_json if p['type'] == proxy_type]
+    proxies = json.loads(json_str)
+    if proxy_type is not None:
+        proxies = [p for p in proxies if p.get('type', None) == proxy_type]
 
     return proxies
 
 
-def get_http_proxy_from_json(proxy_json):
+def get_http_proxy_from_json(json_str):
     """Create a generator of http proxies from given json."""
-    http_proxies = get_proxies_from_json(proxy_json, 'http')
+    http_proxies = get_proxies_from_json(json_str, 'http')
     num_proxies = len(http_proxies)
     i = 0
     while i < num_proxies:
@@ -58,9 +58,9 @@ def get_http_proxy_from_json(proxy_json):
         i += 1
 
 
-def get_https_proxy_from_json(proxy_json):
+def get_https_proxy_from_json(json_str):
     """Create a generator of https proxies from given json."""
-    https_proxies = get_proxies_from_json(proxy_json, 'https')
+    https_proxies = get_proxies_from_json(json_str, 'https')
     num_proxies = len(https_proxies)
     i = 0
     while i < num_proxies:
